@@ -16,15 +16,18 @@ from .sections.subcatch import INFILTRATION_DICT
 
 class SwmmInput(CustomDict):
     """
-    Overall class for an input file.
+    SWMM-input-file class.
 
     Child class of dict.
+    Basically a dict where the section labels of the input file are the keys
+    and the values are the data in these sections.
 
-    Just used for the copy function and to identify ``.inp``-file data.
+    You can create a new empty input file, read existing ones and modify that data.
     """
 
     def __init__(self, *args, custom_section_handler=None, encoding='', force_ignore_case=False, **kwargs):
         """
+        Read or create a SWMM-input-file (___.inp).
 
         Args:
             *args: only for creating the inp-object as a dict.
@@ -276,7 +279,7 @@ class SwmmInput(CustomDict):
         Write a new ``.inp``-file.
 
         Args:
-            filename (str): path/filename of created ``.inp``-file
+            filename (str | Path): path/filename of created ``.inp``-file
             fast (bool): don't use any formatting else format as table
             encoding (str): define encoding for resulting inp-file. Default is same as read inp file or package default ('utf-8')
             custom_sections_order (list[str]): list of section names to preset the order of the section in the created
@@ -940,25 +943,3 @@ class SwmmInput(CustomDict):
 
 
 read_inp_file = SwmmInput.read_file
-
-# def read_inp_file(filename, custom_converter=None, force_ignore_case=False, encoding=DEFAULT_ENCODING):
-#     """
-#     Read ``.inp``-file and convert the sections in pythonic objects.
-#
-#     The sections will be converted when used.
-#
-#     Args:
-#         filename (str): path/filename to .inp file
-#         custom_converter (dict): dictionary of {section: converter/section_type} Default: :py:const:`SECTION_TYPES`
-#         force_ignore_case (bool): SWMM is case-insensitive but python is case-sensitive -> set True to ignore case
-#                                     all text/labels will be set to uppercase
-#         encoding (str): encoding of the .inp-text-file (None -> auto-detect encoding ... takes a few seconds)
-#
-#     Returns:
-#         SwmmInput: dict-like data of the sections in the ``.inp``-file
-#
-#     See Also:
-#         :meth:`SwmmInput.read_file` : Equal functionality.
-#     """
-#     return SwmmInput.read_file(filename, custom_converter=custom_converter, force_ignore_case=force_ignore_case,
-#                                encoding=encoding)
