@@ -1,4 +1,5 @@
-from .reduce_unneeded import reduce_controls, reduce_curves, reduce_raingages, remove_empty_sections, reduce_pattern
+from .reduce_unneeded import (reduce_controls, reduce_curves, reduce_raingages, remove_empty_sections, reduce_pattern,
+                              reduce_timeseries, )
 from ..section_labels import *
 from ..section_lists import LINK_SECTIONS, NODE_SECTIONS
 from ..sections import Tag
@@ -27,7 +28,7 @@ def filter_nodes(inp, final_nodes):
     # __________________________________________
     for section in [INFLOWS, DWF]:
         if section in inp:
-            inp[section] = inp[section].slice_section(final_nodes, by=IDENTIFIERS.Node)
+            inp[section] = inp[section].slice_section(final_nodes, by=IDENTIFIERS.node)
 
     # __________________________________________
     if TAGS in inp:
@@ -55,7 +56,7 @@ def filter_links_within_nodes(inp, final_nodes):
     final_links = set()
     for section in LINK_SECTIONS:
         if section in inp:
-            inp[section] = inp[section].slice_section(final_nodes, by=['FromNode', 'ToNode'])
+            inp[section] = inp[section].slice_section(final_nodes, by=['from_node', 'to_node'])
             final_links |= set(inp[section].keys())
 
     # __________________________________________
@@ -119,9 +120,9 @@ def filter_subcatchments(inp, final_nodes):
     if SUBCATCHMENTS in inp:
         sub_orig = inp[SUBCATCHMENTS].copy()
         # all with an outlet to final_nodes
-        inp[SUBCATCHMENTS] = inp[SUBCATCHMENTS].slice_section(final_nodes, by='Outlet')
+        inp[SUBCATCHMENTS] = inp[SUBCATCHMENTS].slice_section(final_nodes, by='outlet')
         # all with an outlet to an subcatchment
-        inp[SUBCATCHMENTS].update(sub_orig.slice_section(inp[SUBCATCHMENTS].keys(), by='Outlet'))
+        inp[SUBCATCHMENTS].update(sub_orig.slice_section(inp[SUBCATCHMENTS].keys(), by='outlet'))
 
         # __________________________________________
         for section in [SUBAREAS, INFILTRATION, POLYGONS]:
@@ -172,5 +173,6 @@ def create_sub_inp(inp, nodes):
     reduce_curves(inp)
     reduce_raingages(inp)
     reduce_pattern(inp)
+    reduce_timeseries(inp)
     remove_empty_sections(inp)
     return inp
