@@ -24,36 +24,27 @@ class SwmmOutputWarning(UserWarning):
 
 class SwmmOutput(SwmmOutExtract):
     """
-    Read the SWMM Output file (xxx.out).
-
-    Notes:
-        Combined the reader of `swmmtoolbox`_ with the functionality of pandas.
+    SWMM-output-file class.
 
     Attributes:
+        filename (str): Path to the output-file (.out).
         index (pandas.DatetimeIndex): Index of the timeseries of the data.
-        flow_unit (str): Flow unit. One of [`CMS`, `LPS`, `MLD`, `CFS`, `GPM`, `MGD`]
-        labels (dict[str, list]): dictionary of the object labels as list (value) for each object type (keys are: ``link``, ``node``, ``subcatchment``)
+        flow_unit (str): Flow unit. One of [``'CMS', 'LPS', 'MLD', 'CFS', 'GPM', 'MGD'``]
+        labels (dict[str, list]): dictionary of the object labels as list (value) for each object type (keys are: ``'link'``, ``'node'``, ``'subcatchment'``)
         model_properties (dict[str, [dict[str, list]]]): property values for the subcatchments, nodes and links.
-            The Properties for the objects are.
+            The Properties for the objects are...
 
-                - ``subcatchment``
-
-                    - [area]
-
-                - ``node``
-
-                    - [type, invert, max. depth]
-
-                - ``link``
-
-                    - type,
-                    - offsets
-
-                        - ht. above start node invert (ft),
-                        - ht. above end node invert (ft),
-
-                    - max. depth,
-                    - length
+            - ``'subcatchment'``
+                - [area]
+            - ``'node'``
+                - [type, invert, max. depth]
+            - ``'link'``
+                - type,
+                - offsets
+                    - ht. above start node invert (ft),
+                    - ht. above end node invert (ft),
+                - max. depth,
+                - length
 
         pollutant_units (dict[str, str]): Units per pollutant.
         report_interval (datetime.timedelta): Intervall of the index.
@@ -61,16 +52,14 @@ class SwmmOutput(SwmmOutExtract):
         swmm_version (str): SWMM Version
         variables (dict[str, list]): variables per object-type inclusive the pollutants.
         fp (file-like): Stream of the open file.
-        filename (str): Path to the output-file (.out).
-
-    .. _swmmtoolbox: https://github.com/timcera/swmmtoolbox
     """
+    filename: str = ...
     def __init__(self, filename, skip_init=False, encoding=''):
         """
-        Read the SWMM Output file (xxx.out).
+        Read a SWMM-output-file (___.out).
 
         Args:
-            filename(str): Path to the output-file (.out).
+            filename(str | Path): Path to the output-file (.out).
             encoding (str): Encoding of the text in the binary-file (None -> auto-detect encoding ... takes a few seconds | '' -> use default = 'utf-8')
         """
         SwmmOutExtract.__init__(self, filename, skip_init=skip_init, encoding=encoding)
@@ -83,10 +72,9 @@ class SwmmOutput(SwmmOutExtract):
 
         # the main datetime index for the results
         try:
-            self.index = date_range(self.start_date + self.report_interval,
-                                    periods=self.n_periods, freq=self.report_interval)
+            self.index = date_range(self.start_date, periods=self.n_periods, freq=self.report_interval)
         except OutOfBoundsDatetime:
-            self.index = [self.start_date + self.report_interval * i for i in range(self.n_periods)]
+            self.index = [self.start_date * i for i in range(self.n_periods)]
 
     def __repr__(self):
         return f'SwmmOutput(file="{self.filename}")'
@@ -347,21 +335,6 @@ class SwmmOutput(SwmmOutExtract):
 
 read_out_file = SwmmOutput
 
-# def read_out_file(filename):
-#     """
-#     Read the SWMM Output file (xxx.out).
-#
-#     Args:
-#         filename (str): filename of the output file
-#
-#     Returns:
-#         SwmmOutput: output file object
-#
-#     See Also:
-#         :meth:`SwmmOutput.__init__` : Equal functionality.
-#     """
-#     return SwmmOutput(filename)
-
 
 def out2frame(filename):
     """
